ResultExt

Trait ResultExt 

pub trait ResultExt<T> {
    // Required methods
    fn context(self, context: impl Into<String>) -> Result<T>;
    fn with_context<F>(self, f: F) -> Result<T>
       where F: FnOnce() -> String;
}
Helper trait for adding context to Results

This allows chaining context information onto errors in a fluent style.

Required Methods

fn context(self, context: impl Into<String>) -> Result<T>

Add context to an error

Errors

Returns Err(FluxionError) if the underlying result is Err.

fn with_context<F>(self, f: F) -> Result<T>
where F: FnOnce() -> String,

Add context to an error using a closure (lazy evaluation)

Errors

Returns Err(FluxionError) if the underlying result is Err.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<T, E> ResultExt<T> for Result<T, E>
where E: Into<FluxionError>,

Source

fn context(self, context: impl Into<String>) -> Result<T>

Source

fn with_context<F>(self, f: F) -> Result<T>
where F: FnOnce() -> String,

Implementors